blend_score: Score how well a word is a blend of two others

View source: R/blend.R

blend_scoreR Documentation

Score how well a word is a blend of two others

Description

Score how well a word is a blend of two others

Usage

blend_score(blend, word1, word2)

Arguments

blend

Character. Potential blend

word1

Character. First source word

word2

Character. Second source word

Value

Numeric. Score from 0 (poor blend) to 1 (perfect blend)

Examples

blend_score("brunch", "breakfast", "lunch")

covfefe documentation built on Jan. 26, 2026, 5:08 p.m.