| consonant_pairs | R Documentation |
Pairs of consonants that are phonetically similar and commonly confused.
consonant_pairs
A named list mapping consonants to their phonetically similar pairs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.