covfefy: Covfefy any word.

View source: R/covfefe.R

covfefyR Documentation

Covfefy any word.

Description

Attempt to produce your own historic typos. This function takes a word and performs the following algorithm thanks to this codegolf thread:

1. Include all characters up through the first vowel in the word. (co)

2. Identifies the next consonant after the first vowel in the word. (v)

3. Changes that consonant to a phonetically similar consonant. (f)

4. Finds the next vowel after that consonant. (e)

5. Combines the two, and repeats. (fefe)

6. Puts it all together: covfefe

Usage

covfefy(str = "coverage")

Arguments

str

Character string of word to covfefy. Defaults to "coverage".

Examples

covfefy("coverage")
covfefy("programming")
covfefy("president")
covfefy("tropical")

covfefe documentation built on Jan. 26, 2026, 5:08 p.m.