| qwerty_adjacency | R Documentation |
A list containing adjacent keys for each letter on a QWERTY keyboard.
qwerty_adjacency
A named list with 26 elements (a-z), each containing a character vector of adjacent key letters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.