| covfefy | R Documentation |
Attempt to produce your own historic typos. This function takes a word and performs the following algorithm thanks to this codegolf thread:
1. Include all characters up through the first vowel in the word. (co)
2. Identifies the next consonant after the first vowel in the word. (v)
3. Changes that consonant to a phonetically similar consonant. (f)
4. Finds the next vowel after that consonant. (e)
5. Combines the two, and repeats. (fefe)
6. Puts it all together: covfefe
covfefy(str = "coverage")
str |
Character string of word to covfefy. Defaults to "coverage". |
covfefy("coverage")
covfefy("programming")
covfefy("president")
covfefy("tropical")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.